@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_ec2._jsii
 import aws_cdk.core._jsii
@@ -14,9 +14,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-elasticloadbalancing",
-    "1.63.0",
+    "1.64.1",
     __name__[0:-6],
-    "aws-elasticloadbalancing@1.63.0.jsii.tgz",
+    "aws-elasticloadbalancing@1.64.1.jsii.tgz",
 )
 
 __all__ = [
